<?php
declare(strict_types=1);

namespace IntiTest\Db\Connection;

use Doctrine\DBAL\Connection;
use Inti\Db\Connection\ConnectionManager;
use IntiTest\Db\AbstractTestCase;
use IntiTest\Db\ConfigProvider;
use Laminas\ConfigAggregator\ArrayProvider;
use Laminas\ConfigAggregator\ConfigAggregator;
use Laminas\ServiceManager\Exception\ServiceNotFoundException;
use Laminas\ServiceManager\ServiceManager;
use PHPUnit\Framework\TestCase;

/**
 * Class ConnectionManagerTest
 *
 * @package IntiTest\Db\Connection
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-db
 */
final class ConnectionFactoryTest extends AbstractTestCase
{
    public function testWillthrowExceptionForNonExistentConnection()
    {
        $container = $this->getContainer();
        /** @var ConnectionManager $connections */
        $connections = $container->get(ConnectionManager::class);

        $this->expectException(ServiceNotFoundException::class);
        $connections->get('non-existent');
    }

    public function testCanCreateConnection()
    {
        $params = [
            'driver' => 'pdo_sqlite',
            'path' => ':memory:',
        ];

        $container = $this->getContainer([
            'db_connections' => [
                'test' => $params,
            ],
        ]);

        $this->assertTrue($container->has(ConnectionManager::class));

        /** @var ConnectionManager $connections */
        $connections = $container->get(ConnectionManager::class);
        $connection = $connections->get('test');

        $this->assertInstanceOf(Connection::class, $connection);
        /** @noinspection PhpInternalEntityUsedInspection */
        $this->assertEquals($params, $connection->getParams());
    }
}
